@@ -1770,7 +1770,7 @@ exports.clearImmediate = typeof clearImmediate === "function" ? clearImmediate :
 },{"process/browser.js":3,"timers":4}],5:[function(require,module,exports){
 module.exports = Interface;
 
-var m = require("mithril");
+const m = require("mithril");
 
 /**
  * Options main interface
@@ -2034,7 +2034,7 @@ function addEmptyStore(stores) {
 "use strict";
 
 require("chrome-extension-async");
-var Interface = require("./interface");
+const Interface = require("./interface");
 
 run();
 
